==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/es_AR.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiquetas",
    "Update" : "Actualizar",
    "Create" : "Crear",
    "Select tag…" : "Seleccionar etiqueta...",
    "Tagged files" : "Archivos etiquetados",
    "Select tags to filter by" : "Seleccione las etiquetas para el filtro",
    "No tags found" : "No se encontraron etiquetas",
    "Please select tags to filter by" : "Favor de seleccionar etiquetas para el filtro",
    "No files found for the selected tags" : "No se encontraron archivos para las etiquetas seleccionadas",
    "Added system tag %1$s" : "Etiqueta del sistema %1$s agregada",
    "Added system tag {systemtag}" : "Etiqueta del sistema {systemtag} agregada",
    "%1$s added system tag %2$s" : "%1$s agregó la etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} agregó la etiqueta del sistema {systemtag}",
    "Removed system tag %1$s" : "Eliminó la etiqueta del sistema %1$s",
    "Removed system tag {systemtag}" : "Eliminó la etiqueta del sistema {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta del sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta del sistema {systemtag}",
    "You created system tag %1$s" : "Usted creó la etiqueta del sistema %1$s",
    "You created system tag {systemtag}" : "Usted creó la etiqueta del sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creo la etiqueta del sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta del sistema {systemtag}",
    "You deleted system tag %1$s" : "Usted borró la etiqueta del sistema %1$s",
    "You deleted system tag {systemtag}" : "Usted borró la etiqueta del sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s borró la etiqueta del sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} borró la etiqueta del sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Usted actualizó la etiqueta del sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Usted actualizó la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta del sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Usted agregó la etiqueta del sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Usted agregó la etiqueta del sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta del sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta del sistema {systemtag} a {file}",
    "You removed system tag %2$s from %1$s" : "Usted eliminó la etiqueta del sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Usted eliminó la etiqueta del sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eliminó la etiqueta del sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eliminó la etiqueta del sistema  {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible) ",
    "<strong>System tags</strong> for a file have been modified" : "Las <strong>etiquetas del sistema</strong> para un archivo han sido modificadas",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Create and edit collaborative tags. These tags affect all users." : "Crear y editar etiquetas colaborativas. Estas etiquetas afectan a todos los usuarios. ",
    "Select tag …" : "Seleccionar etiqueta ...",
    "Name" : "Nombre",
    "Delete" : "Borrar",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Reset" : "Restaurar",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Size" : "Tamaño",
    "Modified" : "Modificado"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/es_AR.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Etiquetas",
    "Update" : "Actualizar",
    "Create" : "Crear",
    "Select tag…" : "Seleccionar etiqueta...",
    "Tagged files" : "Archivos etiquetados",
    "Select tags to filter by" : "Seleccione las etiquetas para el filtro",
    "No tags found" : "No se encontraron etiquetas",
    "Please select tags to filter by" : "Favor de seleccionar etiquetas para el filtro",
    "No files found for the selected tags" : "No se encontraron archivos para las etiquetas seleccionadas",
    "Added system tag {systemtag}" : "Etiqueta del sistema {systemtag} agregada",
    "Added system tag %1$s" : "Etiqueta del sistema %1$s agregada",
    "%1$s added system tag %2$s" : "%1$s agregó la etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} agregó la etiqueta del sistema {systemtag}",
    "Removed system tag {systemtag}" : "Eliminó la etiqueta del sistema {systemtag}",
    "Removed system tag %1$s" : "Eliminó la etiqueta del sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s eliminó la etiqueta del sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} eliminó la etiqueta del sistema {systemtag}",
    "You created system tag %1$s" : "Usted creó la etiqueta del sistema %1$s",
    "You created system tag {systemtag}" : "Usted creó la etiqueta del sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creo la etiqueta del sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creó la etiqueta del sistema {systemtag}",
    "You deleted system tag %1$s" : "Usted borró la etiqueta del sistema %1$s",
    "You deleted system tag {systemtag}" : "Usted borró la etiqueta del sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s borró la etiqueta del sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} borró la etiqueta del sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Usted actualizó la etiqueta del sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Usted actualizó la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizó la etiqueta del sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizó la etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Usted agregó la etiqueta del sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Usted agregó la etiqueta del sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s agregó la etiqueta del sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} agregó la etiqueta del sistema {systemtag} a {file}",
    "You removed system tag %2$s from %1$s" : "Usted eliminó la etiqueta del sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Usted eliminó la etiqueta del sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s eliminó la etiqueta del sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} eliminó la etiqueta del sistema  {systemtag} de {file}",
    "%s (restricted)" : "%s (restringido)",
    "%s (invisible)" : "%s (invisible) ",
    "<strong>System tags</strong> for a file have been modified" : "Las <strong>etiquetas del sistema</strong> para un archivo han sido modificadas",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Select tag …" : "Seleccionar etiqueta ...",
    "Name" : "Nombre",
    "Public" : "Público",
    "Restricted" : "Restringido",
    "Invisible" : "Invisible",
    "Delete" : "Borrar",
    "Reset" : "Restaurar",
    "No files in here" : "No hay archivos aquí",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Create and edit collaborative tags. These tags affect all users." : "Crear y editar etiquetas colaborativas. Estas etiquetas afectan a todos los usuarios. "
},
"nplurals=2; plural=(n != 1);");
